@@ -13,38 +13,68 @@ theme = ( function ( theme, $, window, document ) {
 
 		var $window            = $( window ),
 			windowWidth        = $window.width(),
-			windowHeight       = $window.height();
+			windowHeight       = $window.height(),
+			flexslider         = {
+						           vars: {}
+					              };
 		
+		/*
+		 * Tiny helper function to add breakpoints.
+		 *
+		 * @param  {number} number           - Number of carousel items that should be visible.
+		 * @return {void}                    - The constructor.
+		 */
+        function getGridSize( number ) {
+            return ( $window.width() <= 768 ) ? 1 : number;
+        }
 
+		
 		/*
 		 * Return an event from callback function to each slider.
 		 *
-		 * @param  {object} thisSlider          - The current slider.
-		 * @param  {object} sliderWrapper       - The current slider wrapper.
-		 * @param  {number} showItems           - Each slider with dynamic min/max ranges.
-		 * @param  {boolean} parallax           - Whether to use parallax effect.
-		 * @param  {string} fireState           - State of fire asynchronously.
-		 * @param  {string} countTotalSelector  - Total counter selector.
-		 * @param  {string} countCurSelector    - Current counter selector.
-		 * @return {number}                     - Index of current slider .
+		 * @param  {object} thisSlider             - The current slider.
+		 * @param  {object} sliderWrapper          - The current slider wrapper.
+		 * @param  {string} fireState              - State of fire asynchronously.
+		 * @return {number}                        - Index of current slider .
 		 */
-        function initslides( sliderWrapper, thisSlider, showItems, parallax, countTotalSelector, countCurSelector, fireState ) {
-
-			var prefix       = 'custom-theme',
-				curIndex     = thisSlider.currentSlide,
-				count        = thisSlider.count,
-				activeClass  = prefix+'-flex-active-slide',
-				prevClass    = activeClass + '-prev',
-				nextClass    = activeClass + '-next',
-				$items       = thisSlider.find( '.item' ),
-				$current     = thisSlider.slides.eq( curIndex ),
-				$prev        = thisSlider.slides.eq( curIndex - 1 ),
-				$next        = thisSlider.slides.eq( thisSlider.animatingTo ),
-				$first       = thisSlider.slides.eq( 0 ),
-				curHeight    = $current.height(),
-				curNhumbs    = thisSlider.data( 'mynavthumbs' );
+        function initslides( sliderWrapper, thisSlider, fireState ) {
 
+			var prefix            = 'custom-theme',
+				curIndex          = thisSlider.currentSlide,
+				count             = thisSlider.count,
+				activeClass       = prefix+'-flex-active-slide',
+				prevClass         = activeClass + '-prev',
+				nextClass         = activeClass + '-next',
+				$items            = thisSlider.find( '.item' ),
+				$current          = thisSlider.slides.eq( curIndex ),
+				$prev             = thisSlider.slides.eq( curIndex - 1 ),
+				$next             = thisSlider.slides.eq( thisSlider.animatingTo ),
+				$first            = thisSlider.slides.eq( 0 ),
+				curHeight         = $current.height(),
+				dataNhumbs        = thisSlider.data( 'my-nav-thumbs' ),
+				dataPNThumbs      = thisSlider.data( 'my-prev-next-thumbs' ),
+				dataTimeline      = thisSlider.data( 'my-nav-timeline' ),
+				dataCountTotal    = thisSlider.data( 'my-count-total' ),
+				dataCountCur      = thisSlider.data( 'my-count-now' ),
+				dataShowItems     = thisSlider.data( 'my-multiple-items' ),
+				dataParallax      = thisSlider.data( 'my-parallax' );
+			
+			
+			if( typeof dataPNThumbs === typeof undefined ) dataPNThumbs = false;
+			if( typeof dataTimeline === typeof undefined ) dataTimeline = false;
+			if( typeof dataCountTotal === typeof undefined ) dataCountTotal = false;
+			if( typeof dataCountCur === typeof undefined ) dataCountCur = false;
+			if( typeof dataParallax === typeof undefined ) dataParallax = false;	
+			
+			
+			//Total counter selector
+			//Current counter selector.
+			var countTotalSelector = ( dataCountTotal ) ? $( dataCountTotal ) : $( 'p.count em.count' ), 
+				countCurSelector   = ( dataCountCur ) ? $( dataCountCur ) : $( 'p.count em.current' );
+			
+			
 
+			
 			// Fires when the slider loads the first slide.
 			// Fires after each slider animation completes.
 			if ( fireState == 'start' || fireState == 'after' ) {
@@ -52,8 +82,75 @@ theme = ( function ( theme, $, window, document ) {
 				//Remove the slider loading
 				//-------------------------------------
 				thisSlider.removeClass( prefix+'-flexslider-loading' );
+				
+
+				
+				//With Timeline
+				//-------------------------------------	
+				if ( dataTimeline && dataTimeline != '' ) {
+					var curPerMinWidth = curIndex/count*100 + '%',
+						curPerMaxWidth = (curIndex + 1)/count*100 + '%',
+						curTotalWidth  = $( dataTimeline ).width();
+				
+					//Fires animation effect of an element width.
+					$( dataTimeline ).find( '> span' ).css( {
+						'width'     : curTotalWidth,
+						'transition': 'all ' + parseFloat( thisSlider.vars.slideshowSpeed - thisSlider.vars.animationSpeed ) + 'ms linear'	
+					} );	
+					
+	
+				}
+				
+
+				
+				
+				//Display Next/Prev image thumbnail in navigation
+				//-------------------------------------		
+				if ( dataPNThumbs && dataPNThumbs != '' ) {
+					var prevIndex  = curIndex - 1,
+						nextIndex  = thisSlider.animatingTo + 1,
+						pimg       = '',
+						nimg       = '',
+						$plink     = $( dataPNThumbs+'> a' ),
+						$plinkPrev = $plink.filter( '.thumb-prev' ),
+						$plinkNext = $plink.filter( '.thumb-next' );
+
+					$plinkPrev.removeClass( 'disabled' );
+					$plinkNext.removeClass( 'disabled' );
+
+					if ( !thisSlider.vars.animationLoop ) {
+						if ( prevIndex === -1 ) $plinkPrev.addClass( 'disabled' );
+						if ( nextIndex === thisSlider.last + 1 ) $plinkNext.addClass( 'disabled' );	
+					} else {
+						if ( prevIndex === -1 ) prevIndex = thisSlider.last;
+						if ( nextIndex === thisSlider.last + 1 ) nextIndex = 0;
+					}
+
+					//Get images URL
+					pimg = thisSlider.slides.eq( prevIndex ).find( 'img' ).attr( 'src' );
+					nimg = thisSlider.slides.eq( nextIndex ).find( 'img' ).attr( 'src' );
 
 
+					if ( $( dataPNThumbs ).length > 0 ) {
+
+						$plink.attr( 'href', 'javascript:void(0);' );
+
+
+						if ( typeof pimg != typeof undefined ) $plinkPrev.attr( 'data-goto', prevIndex ).find( '> span' ).html('<img src="'+pimg+'" alt="">');
+						if ( typeof nimg != typeof undefined ) $plinkNext.attr( 'data-goto', nextIndex ).find( '> span' ).html('<img src="'+nimg+'" alt="">');		
+
+
+						$plink.on( 'click', function( e ) {
+							e.preventDefault();
+
+							thisSlider.flexslider( parseInt( $( this ).attr( 'data-goto' ) ) );
+						});
+					}	
+				}
+
+				
+		
+				
 				// Fires local videos asynchronously with slider switch.
 				//-------------------------------------
 				videoEmbedInit( $items, false );
@@ -80,9 +177,9 @@ theme = ( function ( theme, $, window, document ) {
 
 				//Thumbnail ControlNav Pattern
 				//-------------------------------------
-				if( typeof curNhumbs != typeof undefined ) {
-					$( '.custom-theme-flexslider-thumbs'+curNhumbs+' > ul > li' ).removeClass( 'active' );
-					$( '.custom-theme-flexslider-thumbs'+curNhumbs+' > ul > li' ).eq( curIndex ).addClass( 'active' );			
+				if ( dataNhumbs && dataNhumbs != '' ) {
+					$( '.custom-theme-flexslider-thumbs'+dataNhumbs+' > ul > li' ).removeClass( 'active' );
+					$( '.custom-theme-flexslider-thumbs'+dataNhumbs+' > ul > li' ).eq( curIndex ).addClass( 'active' );			
 				}
 
 
@@ -103,21 +200,29 @@ theme = ( function ( theme, $, window, document ) {
 				//Return an event from callback function to each slider 
 				//with dynamic min/max ranges.
 				//-------------------------------------
-				if( typeof showItems != typeof undefined && showItems != '' && showItems != 0 ) {
+				if( typeof dataShowItems != typeof undefined && dataShowItems != '' && dataShowItems != 0 ) {
 
 
 					$items.removeClass( activeClass );
 					$items.removeClass( prevClass );
 					$items.removeClass( nextClass );
 
-					//Focus slider
-					$items.eq( parseFloat( curIndex+1 ) ).addClass( activeClass );
+					if ( windowWidth <= 768 ) {
+						
+						//Focus slider
+						$items.eq( parseFloat( curIndex ) ).addClass( activeClass );	
+						
+					} else {
+						//Focus slider
+						$items.eq( parseFloat( curIndex+1 ) ).addClass( activeClass );
 
-					//Previous slider
-					$items.eq( parseFloat( curIndex ) ).addClass( prevClass );
+						//Previous slider
+						$items.eq( parseFloat( curIndex ) ).addClass( prevClass );
 
-					//Next slider
-					$items.eq( parseFloat( curIndex+2 ) ).addClass( nextClass );	
+						//Next slider
+						$items.eq( parseFloat( curIndex+2 ) ).addClass( nextClass );	
+					}
+					
 				}
 
 
@@ -137,18 +242,39 @@ theme = ( function ( theme, $, window, document ) {
 			// Fires asynchronously with each slider animation.
 			if ( fireState == 'before' ) {
 				
+				//Common images style
+				//-------------------------------------	
 				$next.find( 'img' ).addClass( 'active' );
-				
 				$current.find( 'img' ).removeClass( 'active' );
 				$prev.find( 'img' ).removeClass( 'active' );
 				$first.find( 'img' ).removeClass( 'active' );
+
+				//With Timeline
+				//-------------------------------------	
+				if ( dataTimeline && dataTimeline != '' ) {
+			
+					//Fires animation effect of an element width.
+					$( dataTimeline ).find( '> span' ).css( {
+						'width'     : 0,
+						'transition': 'all 100ms linear'	
+					} );
+					
+
+	
+				}	
+				
+				
 			}
 			
 			
 			// Fires when the slider reaches the last slide (asynchronous).
 			if ( fireState == 'end' ) {
 				
+				
+				//Common images style
+				//-------------------------------------	
 				$first.find( 'img' ).addClass( 'active' );
+		
 				
 			}
 			
@@ -159,7 +285,7 @@ theme = ( function ( theme, $, window, document ) {
 				
 				//Return an event from callback function to each slider to make parallax effect.
 				//-------------------------------------
-				if ( parallax ) {
+				if ( dataParallax ) {
 				
 					
 					var dir = 'left';
@@ -193,12 +319,20 @@ theme = ( function ( theme, $, window, document ) {
 		 * @return {void}                    - The constructor.
 		 */
 		function videoEmbedInit( wrapper, play ) {
-			wrapper.find( '.web-video-embed' ).each( function()  {
+			wrapper.find( '.slider-video-embed' ).each( function()  {
 				var $this         = $( this ),
+					videoWrapperW = $this.closest( '[data-embed-video-wrapper]' ).width(),
+					videoWrapperH = $this.closest( '[data-embed-video-wrapper]' ).height(),
 					curVideoID    = $this.find( '.video-js' ).attr( 'id' ),
+					dataControls  = $this.data( 'embed-video-controls' ),
 					dataAuto      = $this.data( 'embed-video-autoplay' ),
-					dataLoop      = $this.data( 'embed-video-loop' );
+					dataLoop      = $this.data( 'embed-video-loop' ),
+					dataW         = $this.data( 'embed-video-width' ),
+					dataH         = $this.data( 'embed-video-height' ),
+					$replayBtn    = $( '#'+curVideoID+'-replay-btn' );
 
+				
+				if ( videoWrapperH == 0 ) videoWrapperH = videoWrapperW/1.77777777777778;
 			
 				if( typeof dataAuto === typeof undefined ) {
 					dataAuto = true;
@@ -207,6 +341,28 @@ theme = ( function ( theme, $, window, document ) {
 					dataLoop = true;
 				}
 				
+				if( typeof dataControls === typeof undefined ) {
+					dataControls = false;
+				}		
+				
+			
+				if( typeof dataW === typeof undefined || dataW == 'auto' ) {
+					dataW = videoWrapperW;
+				}	
+
+				if( typeof dataH === typeof undefined || dataH == 'auto' ) {
+					dataH = videoWrapperH;
+				}
+				
+
+
+				
+				//Add replay button to video 
+				if ( $replayBtn.length == 0 ) {
+					$this.after( '<span class="web-video-replay" id="'+curVideoID+'-replay-btn"></span>' );
+				}
+				
+				
 				//HTML5 video autoplay on mobile revisited
 				if ( dataAuto && windowWidth <= 768 ) {
 					$this.find( '.video-js' ).attr({
@@ -216,26 +372,108 @@ theme = ( function ( theme, $, window, document ) {
 					});
 				}
 
-				var myPlayer = videojs( curVideoID );
+				var myPlayer = videojs( curVideoID, {
+										  width     : dataW,
+										  height    : dataH,
+										  loop      : dataLoop,
+										  controlBar: {
+											  muteToggle : false,
+											  autoplay   : dataAuto,
+											  loop       : dataLoop,
+											  controls   : true,
+											  controlBar : {
+												  muteToggle: false
+											  }
+										  }
 
 
+										});
+
+				
+
 				myPlayer.ready(function() {
+					
+			
+					/* ---------  Video initialize */
+					myPlayer.on( 'loadedmetadata', function() {
 
-					//Pause the video when it is not current slider
+						//Get Video Dimensions
+						var curW    = this.videoWidth(),
+							curH    = this.videoHeight(),
+							newW    = curW,
+							newH    = curH;
+
+						newW = videoWrapperW;
+
+						//Scaled/Proportional Content 
+						newH = curH*(newW/curW);
+						
+					
+						if ( !isNaN( newW ) && !isNaN( newH ) )  {
+							myPlayer
+								.width( newW )
+								.height( newH );	
+							
+							$this.css( 'height', newH );
+						}
+
+
+
+						//Show this video wrapper
+						$this.css( 'visibility', 'visible' );
+
+						//Hide loading effect
+						$this.find( '.vjs-loading-spinner, .vjs-big-play-button' ).hide();
+
+					});		
+
+		
+				
+					/* ---------  Set, tell the player it's in fullscreen  */
+					if ( dataAuto ) {
+						myPlayer.play();
+					}
+
+
+					/* ---------  Disable control bar play button click */
+					if ( !dataControls ) {
+						myPlayer.controls( false );
+					}
+
+					
+					/* ---------  Pause the video when it is not current slider  */
 					if ( !play ) {
 						myPlayer.pause();
 						myPlayer.currentTime(0);
 					} else {
-						if ( dataAuto && dataLoop ) {
+						if ( dataAuto ) {
 
 							myPlayer.currentTime(0);
 							myPlayer.play();
+							$replayBtn.hide();
 
 							//Should the video go to the beginning when it ends
-
 							myPlayer.on( 'ended', function () { 
-								myPlayer.currentTime(0);
-								myPlayer.play();
+								
+								if ( dataLoop ) {
+									myPlayer.currentTime(0);
+									myPlayer.play();	
+								} else {
+									//Replay this video
+									myPlayer.currentTime(0);
+									
+									$replayBtn
+										.show()
+										.off( 'click' )
+										.on( 'click', function( e ) {
+											e.preventDefault();
+
+											myPlayer.play();
+											$replayBtn.hide();
+
+										});						
+								}
+							
 							});		
 
 
@@ -426,25 +664,32 @@ theme = ( function ( theme, $, window, document ) {
 		 */
 		var $sliderDefault = $( '.custom-theme-flexslider' );
 		$sliderDefault.each( function()  {
-			var $this           = $( this ),
-				dataSpeed       = $this.data( 'speed' ),
-				dataDrag        = $this.data( 'draggable' ),
-				dataWheel       = $this.data( 'wheel' ),
-				dataTiming      = $this.data( 'timing' ),
-				dataLoop        = $this.data( 'loop' ),
-				dataPrev        = $this.data( 'prev' ),
-				dataNext        = $this.data( 'next' ),
-				dataAnim        = $this.data( 'animation' ),
-				dataPaging      = $this.data( 'paging' ),
-				dataArrows      = $this.data( 'arrows' ),
-				dataAuto        = $this.data( 'auto' ),
-				dataNhumbs      = $this.data( 'mynavthumbs' ),
-				dataCountTotal  = $this.data( 'mycounttotal' ),
-				dataCountCur    = $this.data( 'mycountcur' ),
-				customConID     = $this.data( 'mycontrols' ),
-				dataShowItems   = $this.data( 'myshow' ),
-				dataParallax    = $this.data( 'myparallax' ),
-				dataSync        = $this.data( 'mysync' );
+			var $this             = $( this ),
+				dataSpeed         = $this.data( 'speed' ),
+				dataDrag          = $this.data( 'draggable' ),
+				dataWheel         = $this.data( 'wheel' ),
+				dataTiming        = $this.data( 'timing' ),
+				dataLoop          = $this.data( 'loop' ),
+				dataPrev          = $this.data( 'prev' ),
+				dataNext          = $this.data( 'next' ),
+				dataAnim          = $this.data( 'animation' ),
+				dataPaging        = $this.data( 'paging' ),
+				dataArrows        = $this.data( 'arrows' ),
+				dataAuto          = $this.data( 'auto' ),
+				dataNhumbs        = $this.data( 'my-nav-thumbs' ),
+				dataPNThumbs      = $this.data( 'my-prev-next-thumbs' ),
+				dataTimeline      = $this.data( 'my-nav-timeline' ),
+				dataCountTotal    = $this.data( 'my-count-total' ),
+				dataCountCur      = $this.data( 'my-count-now' ),
+				customConID       = $this.data( 'my-controls' ),
+				dataShowItems     = $this.data( 'my-multiple-items' ),
+				dataParallax      = $this.data( 'my-parallax' ),
+				dataSync          = $this.data( 'my-sync' );
+			
+			
+			//Fires local videos asynchronously with slider switch.
+			videoEmbedInit( $this.find( '.item' ), false );
+			
 			
 			// Custom Controls
 			var myControlsContainer, myCustomDirectionNav;
@@ -470,11 +715,15 @@ theme = ( function ( theme, $, window, document ) {
 			if( typeof dataDrag === typeof undefined ) dataDrag = false;
 			if( typeof dataWheel === typeof undefined ) dataWheel = false;
 			if( typeof dataNhumbs === typeof undefined ) dataNhumbs = false;
+			if( typeof dataPNThumbs === typeof undefined ) dataPNThumbs = false;
+			if( typeof dataTimeline === typeof undefined ) dataTimeline = false;
 			if( typeof dataCountTotal === typeof undefined ) dataCountTotal = false;
 			if( typeof dataCountCur === typeof undefined ) dataCountCur = false;
 			if( typeof dataParallax === typeof undefined ) dataParallax = false;
 		
 			
+
+			
 			//Make slider image draggable 
 			if ( dataDrag ) slidesExDraggable( $this );
 
@@ -489,6 +738,7 @@ theme = ( function ( theme, $, window, document ) {
 				dataLoop = false;
 			}
 			
+		
 			
 			//Show number of items
 			var my_itemWidth = 0, 
@@ -500,20 +750,15 @@ theme = ( function ( theme, $, window, document ) {
 				
 			    my_itemWidth = 1;
 				my_move      = 1;
-				my_minItems  = dataShowItems;
-				my_maxItems  = dataShowItems;
-				
-				if ( windowWidth <= 768 ) {
-					my_minItems  = 1;
-					my_maxItems  = 1;	
-				}
+				my_minItems  = getGridSize( dataShowItems );
+				my_maxItems  = getGridSize( dataShowItems );
 				
 			} 
 			
 			
 			// Determine if this slider is added with a synchronization event
-			$( '[data-mysync]' ).each( function()  {
-				var curSync      = $( this ).data( 'mysync' ),
+			$( '[data-my-sync]' ).each( function()  {
+				var curSync      = $( this ).data( 'my-sync' ),
 					thisSliderID = $this.attr( 'id' );
 				
 				
@@ -521,8 +766,9 @@ theme = ( function ( theme, $, window, document ) {
 					curSync = curSync.toString().replace( '#', '' ).replace( '.', '' );
 				}
 				
+				
 				if( typeof thisSliderID != typeof undefined && thisSliderID == curSync ) {
-					dataAuto = false;
+					dataAuto = false; //Set it not to scroll automatically
 					dataPaging = false;
 					
 					// break out of jQuery each Loop
@@ -531,13 +777,7 @@ theme = ( function ( theme, $, window, document ) {
 
 
 			});
-			
-			
-			//Display counter
-			var $countTotal = ( dataCountTotal ) ? $( dataCountTotal ) : $( 'p.count em.count' ), 
-				$countCur   = ( dataCountCur ) ? $( dataCountCur ) : $( 'p.count em.current' );
-			
-			
+
 
 			
 			$this.flexslider({
@@ -563,12 +803,19 @@ theme = ( function ( theme, $, window, document ) {
 				
 				//Fires when the slider loads the first slide.
 				start: function( slider ) {
-					initslides( $this, slider, dataShowItems, dataParallax, $countTotal, $countCur, 'start' );
+					
+					//set slider instance to flexslider variable
+					if( typeof dataShowItems != typeof undefined && dataShowItems != '' && dataShowItems != 0 ) {
+					    flexslider = slider;		
+					}
+					
+					initslides( $this, slider, 'start' );
+
 				},
 				
 				//Fires asynchronously with each slider animation.
 				before: function( slider ) {
-					initslides( $this, slider, dataShowItems, dataParallax, $countTotal, $countCur, 'before' );
+					initslides( $this, slider, 'before' );
 					
 					// Call the updateChildrenSlides which itterates through all children slides 
 					if( typeof dataSync != typeof undefined && dataSync != '' && dataSync != 0 ) {
@@ -581,12 +828,14 @@ theme = ( function ( theme, $, window, document ) {
 				
 				//Fires after each slider animation completes.
 				after: function( slider ) {
-					initslides( $this, slider, dataShowItems, dataParallax, $countTotal, $countCur, 'after' );
+					initslides( $this, slider, 'after' );
+
+					
 				},
 				
 				//Fires when the slider reaches the last slide (asynchronous).
 				end: function( slider ) {
-					initslides( $this, slider, dataShowItems, dataParallax, $countTotal, $countCur, 'end' );
+					initslides( $this, slider, 'end' );
 				}
 			});
 			
@@ -611,6 +860,19 @@ theme = ( function ( theme, $, window, document ) {
 				$sliderDefault.each( function() {
 					
 					if ( $( this ).length > 0 ) {
+
+						// check grid size on resize event
+						var dataShowItems = $( this ).data( 'my-multiple-items' );
+		
+						
+						if( typeof dataShowItems != typeof undefined && dataShowItems != '' && dataShowItems != 0 ) {
+
+							var gridSize = getGridSize( dataShowItems );
+							flexslider.vars.minItems = gridSize;
+							flexslider.vars.maxItems = gridSize;
+							
+						}
+						
 						$( this ).data( 'flexslider' ).setup();
 					}			
 					
